# Credits

## Maintainer
 - Alexandre Poux (alexandre.poux@coria.fr)

## Core Contributers

### Technical part
 - Alexandra Poux (alexandre.poux@coria.fr)  

### Scientific part
 - Florian Lespinasse  (florian.lespinasse@coria.fr)  
 - Tanguy Davin (davint@coria.fr)

## Initial devellopment
 - Alexandra Brisset  
   